@@ -1,12 +1,31 @@
-##############################################################################
-#
-# Copyright (c) 2003 Connexions Projects and Contributors. All Rights Reserved.
-#
-##############################################################################
-""" Basic usergroup tool.
+# -*- coding: utf-8 -*-
+## GroupUserFolder
+## Copyright (C)2006 Ingeniweb
 
-$Id: GroupsTool.py 10462 2005-08-01 16:20:35Z pjgrizel $
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+
+## You should have received a copy of the GNU General Public License
+## along with this program; see the file COPYING. If not, write to the
+## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+## Copyright (c) 2003 The Connexions Project, All Rights Reserved
+## initially written by J Cameron Cooper, 11 June 2003
+## concept with Brent Hendricks, George Runyan
 """
+Basic usergroup tool.
+"""
+__version__ = "$Revision:  $"
+# $Source:  $
+# $Id: GroupsTool.py 33400 2006-11-11 11:59:47Z shh42 $
+__docformat__ = 'restructuredtext'
 
 from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import getToolByName
@@ -16,10 +35,17 @@ from Globals import InitializeClass, DTMLFile, MessageDialog
 from Acquisition import aq_base
 from AccessControl.User import nobody
 from AccessControl import ClassSecurityInfo
-from Products.CMFCore.CMFCorePermissions import View
-from Products.CMFCore.CMFCorePermissions import AccessContentsInformation
-from Products.CMFCore.CMFCorePermissions import ManagePortal
-from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
+from ZODB.POSException import ConflictError
+# BBB CMF < 1.5
+try:
+    from Products.CMFCore.permissions import ManagePortal
+    from Products.CMFCore.permissions import View
+    from Products.CMFCore.permissions import ViewManagementScreens
+except ImportError:
+    from Products.CMFCore.CMFCorePermissions import ManagePortal
+    from Products.CMFCore.CMFCorePermissions import View
+    from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
+
 from GroupsToolPermissions import AddGroups
 from GroupsToolPermissions import ManageGroups
 from GroupsToolPermissions import DeleteGroups
@@ -141,16 +167,6 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
             return 1
         return 0
 
-##    security.declarePrivate('getPureUserNames')
-##    def getPureUserNames(self):
-##        """Get the usernames (ids) of only users. """
-##        return self.acl_users.getPureUserNames()
-
-##    security.declarePrivate('getPureUsers')
-##    def getPureUsers(self):
-##        """Get the actual (unwrapped) user objects of only users. """
-##        return self.acl_users.getPureUsers()
-
     security.declareProtected(View, 'searchForGroups')
     def searchForGroups(self, REQUEST = {}, **kw):
         """Return a list of groups meeting certain conditions. """
@@ -455,13 +471,6 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
         parent = self.aq_inner.aq_parent
         base = getattr(parent, 'aq_base', None)
         if hasattr(base, 'portal_groupdata'):
-##             # Apply any role mapping if we have it
-##             if hasattr(self, 'role_map'):
-##                 for portal_role in self.role_map.keys():
-##                     if (self.role_map.get(portal_role) in u.roles and
-##                             portal_role not in u.roles):
-##                         u.roles.append(portal_role)
-
             # Get portal_groupdata to do the wrapping.
             Log(LOG_DEBUG, "parent", parent)
             gd = getToolByName(parent, 'portal_groupdata')
@@ -469,28 +478,14 @@ class GroupsTool (UniqueObject, SimpleItem, ActionProviderBase, ):
             try:
                 #log("wrapping group %s" % g)
                 portal_group = gd.wrapGroup(g)
-
-                # Check for the member area creation flag and
-                # take appropriate (non-) action
-
-                # DISABLED: do it upon group creation
-                #if self.getGroupWorkspacesCreationFlag():
-                #    self.createGrouparea(portal_group.getGroupName())
-
                 return portal_group
-
+            except ConflictError:
+                raise
             except:
-                from zLOG import LOG, ERROR
-                import sys
-                type,value,tb = sys.exc_info()
-                try:
-                    LOG('GroupsTool', ERROR, 'Error during wrapGroup:', "\nType:%s\nValue:%s\n" % (type,value))
-                finally:
-                    tb = None       # Avoid leaking frame
-                pass
+                import logging
+                logger = logging.getLogger('GroupUserFolder.GroupsTool')
+                logger.exception('Error during wrapGroup')
         # Failed.
         return g
 
-
-
 InitializeClass(GroupsTool)
